@@ -81,9 +81,8 @@ def define_stack_name(template=None):
     :param troposphere.Template template: the template to add it to.
     :return:
     """
-    if template:
-        if USE_STACK_NAME_CON_T not in template.conditions:
-            template.add_condition(USE_STACK_NAME_CON_T, USE_STACK_NAME_CON)
+    if template and USE_STACK_NAME_CON_T not in template.conditions:
+        template.add_condition(USE_STACK_NAME_CON_T, USE_STACK_NAME_CON)
     return If(
         USE_STACK_NAME_CON_T, Ref("AWS::StackName"), Ref(cfn_params.ROOT_STACK_NAME)
     )
