@@ -19,27 +19,27 @@
 Module for the ComposeXSettings class
 """
 
+from datetime import datetime as dt
+from json import dumps
+
 import boto3
 from botocore.exceptions import ClientError
-from json import dumps
-from datetime import datetime as dt
 
 from ecs_composex.common import keyisset, LOG, load_composex_file
 from ecs_composex.common.aws import get_account_id, get_region_azs
-from ecs_composex.vpc.vpc_params import (
-    VPC_ID_T,
-    PUBLIC_SUBNETS_T,
-    APP_SUBNETS_T,
-    STORAGE_SUBNETS_T,
-)
-from ecs_composex.ecs.ecs_params import CLUSTER_NAME
-from ecs_composex.common.cfn_params import USE_FLEET_T
 from ecs_composex.common.aws import (
     lookup_vpc_id,
     lookup_vpc_from_tags,
     lookup_subnets_from_tags,
     lookup_subnets_ids,
 )
+from ecs_composex.common.cfn_params import USE_FLEET_T
+from ecs_composex.vpc.vpc_params import (
+    VPC_ID_T,
+    PUBLIC_SUBNETS_T,
+    APP_SUBNETS_T,
+    STORAGE_SUBNETS_T,
+)
 
 
 class ComposeXSettings(object):
@@ -50,7 +50,6 @@ class ComposeXSettings(object):
     name_arg = "Name"
     cluster_name_arg = "ClusterName"
 
-    create_cluster_arg = "CreateCluster"
     create_vpc_arg = "CreateVpc"
     create_ec2_arg = "AddComputeResources"
     create_spotfleet_arg = USE_FLEET_T
@@ -115,9 +114,6 @@ class ComposeXSettings(object):
         self.lookup_vpc = False
         self.set_vpc(kwargs)
 
-        self.create_cluster = None
-        self.cluster_name = None
-        self.set_cluster_settings(kwargs)
         self.deploy = True if keyisset(self.deploy_arg, kwargs) else False
 
     def __repr__(self):
@@ -159,7 +155,10 @@ class ComposeXSettings(object):
                 )
                 self.set_vpc_default_settings()
         elif not keyisset("x-vpc", self.compose_content):
-            self.set_cli_vpc_settings(kwargs)
+            LOG.warning(
+                "No x-vpc definition found in the docker-compose file. Creating a new VPC with default settings"
+            )
+            self.set_vpc_defaults(kwargs)
 
     def override_session(self, session, profile_name):
         """
@@ -193,19 +192,6 @@ class ComposeXSettings(object):
             else self.default_output_dir
         )
 
-    def set_cluster_settings(self, kwargs):
-        """
-        Method to set cluster settings based on kwargs
-        """
-        self.create_cluster = (
-            True if keyisset(self.create_cluster_arg, kwargs) else False
-        )
-        self.cluster_name = (
-            kwargs[self.cluster_name_arg]
-            if keyisset(self.cluster_name_arg, kwargs)
-            else None
-        )
-
     def lookup_vpc_id(self, vpc_id_settings):
         """
         Method to confirm or find VPC ID
@@ -311,36 +297,20 @@ class ComposeXSettings(object):
             else self.default_vpc_cidr
         )
 
-    def set_cli_vpc_settings(self, kwargs):
+    def set_vpc_defaults(self, kwargs):
         """
         Method to set the values of subnets if present in kwargs
 
         :param dict kwargs:
         :return:
         """
-        self.vpc_cidr = (
-            kwargs[self.vpc_cidr_arg]
-            if keyisset(self.vpc_cidr_arg, kwargs)
-            else self.default_vpc_cidr
-        )
         self.create_vpc = True
-        vpc_id = kwargs[VPC_ID_T] if keyisset(VPC_ID_T, kwargs) else None
-        self.single_nat = (
-            kwargs[self.single_nat_arg]
-            if keyisset(self.single_nat_arg, kwargs)
-            else True
-        )
-        public_subnets = (
-            kwargs[PUBLIC_SUBNETS_T] if keyisset(PUBLIC_SUBNETS_T, kwargs) else None
-        )
-        storage_subnets = (
-            kwargs[STORAGE_SUBNETS_T] if keyisset(STORAGE_SUBNETS_T, kwargs) else None
-        )
-        app_subnets = kwargs[APP_SUBNETS_T] if keyisset(APP_SUBNETS_T, kwargs) else None
-        setattr(self, VPC_ID_T, vpc_id)
-        setattr(self, APP_SUBNETS_T, app_subnets)
-        setattr(self, STORAGE_SUBNETS_T, storage_subnets)
-        setattr(self, PUBLIC_SUBNETS_T, public_subnets)
+        self.vpc_cidr = self.default_vpc_cidr
+        self.single_nat = True
+        setattr(self, VPC_ID_T, None)
+        setattr(self, APP_SUBNETS_T, None)
+        setattr(self, STORAGE_SUBNETS_T, None)
+        setattr(self, PUBLIC_SUBNETS_T, None)
 
     def set_vpc_default_settings(self):
         LOG.info(
@@ -394,13 +364,3 @@ class ComposeXSettings(object):
                 self.bucket_name = None
                 self.upload = False
                 self.no_upload = True
-
-    def create_root_stack_parameters_from_input(self):
-        """
-        Method to create the parameters for the root stack from CLI input.
-        :return:
-        """
-        parameters = {}
-        if self.cluster_name != CLUSTER_NAME.Default:
-            parameters[CLUSTER_NAME.title] = self.cluster_name
-        return parameters
