@@ -42,7 +42,7 @@ from troposphere.cloudformation import Stack
 from troposphere.ec2 import LaunchTemplate, TagSpecifications
 
 from ecs_composex.common import keyisset, NONALPHANUM, LOG, add_parameters
-from ecs_composex.common.stacks import XModuleStack, ComposeXStack
+from ecs_composex.common.stacks import ComposeXStack
 
 
 def define_tag_parameter_title(tag_name):
@@ -85,36 +85,29 @@ def define_extended_tags(tags):
     return None
 
 
-def generate_tags_parameters(composex_content):
+def generate_tags_parameters(tags):
     """
     Function to generate a list of parameters used for the tags values
 
-    :param composex_content: docker composeX file content
-    :type composex_content: dict
     :return: list of parameters and tags to add to objects
     :rtype: tuple
     """
-    if not keyisset("x-tags", composex_content):
-        LOG.info("No x-tags found. Skipping")
-        return []
-    xtags = composex_content["x-tags"]
-    object_tags = define_extended_tags(xtags)
     parameters = []
-    for tag in xtags:
+    for tag in tags:
         parameters.append(
             Parameter(
                 define_tag_parameter_title(tag["name"])
-                if isinstance(xtags, list)
+                if isinstance(tags, list)
                 else define_tag_parameter_title(tag),
                 Type="String",
                 MinLength=2,
                 MaxLength=128,
                 AllowedPattern=r"[\x20-\x7E]+",
                 ConstraintDescription="Must be ASCII",
-                Default=tag["value"] if isinstance(xtags, list) else xtags[tag],
+                Default=tag["value"] if isinstance(tags, list) else tags[tag],
             )
         )
-    return parameters, object_tags
+    return parameters
 
 
 def expand_launch_template_tags_specs(lt, tags):
@@ -145,32 +138,49 @@ def expand_launch_template_tags_specs(lt, tags):
         LOG.error(error)
 
 
+def merge_tags_lists(x_data, y_data):
+    x_keys = [x["Key"] for x in x_data]
+    result = [{a["Key"]: a["Value"]} for a in x_data]
+    for count, tag in enumerate(y_data):
+        if tag["Key"] not in x_keys:
+            result.append({y_data[count]["Key"]: y_data[count]["Value"]})
+    return result
+
+
 def add_object_tags(obj, tags):
     """
     Function to add tags to the object if the object supports it
 
     :param obj: Troposphere object to add the tags to
-    :param tags: list of tags as defined in Docker composeX file
-    :type tags: dict or list
+    :param troposphere.Tags tags: list of tags as defined in Docker composeX file
     """
     if tags is None:
         return
     clean_tags = copy.deepcopy(tags)
     if isinstance(obj, LaunchTemplate):
         expand_launch_template_tags_specs(obj, clean_tags)
+        return
     if hasattr(obj, "props") and "Tags" not in obj.props:
+        LOG.debug(f"Item {obj.title} - {obj.resource_type} does not support tags")
         return
     if hasattr(obj, "Tags") and isinstance(getattr(obj, "Tags"), Tags):
         LOG.debug(f"Adding the new tags {clean_tags} to {obj}")
-        existing_tags = getattr(obj, "Tags")
-        new_tags = existing_tags + clean_tags
-        setattr(obj, "Tags", new_tags)
+        existing_tags = getattr(obj, "Tags").to_dict()
+        new_tags = clean_tags.to_dict()
+        result = merge_tags_lists(existing_tags, new_tags)
+        result_tags = Tags(*result)
+        LOG.debug(result_tags)
+        setattr(obj, "Tags", result_tags)
     elif not hasattr(obj, "Tags"):
-        LOG.debug(f"Adding tags to {obj}")
-        setattr(obj, "Tags", tags)
+        LOG.debug(f"No existing tags. Adding tags to {obj}")
+        setattr(obj, "Tags", clean_tags)
 
 
-def add_all_tags(root_template, params_and_tags):
+def default_tags():
+    return Tags(CreatedByComposeX=True)
+
+
+def add_all_tags(root_template, settings, params=None, xtags=None):
     """
     Function to go through all stacks of a given template and update the template
     It will recursively render sub stacks defined.
@@ -178,23 +188,34 @@ def add_all_tags(root_template, params_and_tags):
 
     :param root_template: the root template to iterate over the resources.
     :type root_template: troposphere.Template
-    :param params_and_tags: parameters and tags to add to the stack resources
-    :type params_and_tags: ()
+    :param ecs_composex.common.settings.ComposeXSettings settings:
     """
-    if not params_and_tags:
-        return None
-    resources = root_template.resources
+    if not params or not xtags:
+        if not keyisset("x-tags", settings.compose_content):
+            xtags = default_tags()
+            params = None
+        else:
+            tags = settings.compose_content["x-tags"]
+            params = generate_tags_parameters(tags)
+            xtags = define_extended_tags(tags)
+            xtags += default_tags()
+
+    resources = root_template.resources if root_template else []
     for resource_name in resources:
         resource = resources[resource_name]
-        if isinstance(resource, (XModuleStack, ComposeXStack)):
+        if isinstance(resource, ComposeXStack) or issubclass(
+            type(resource), ComposeXStack
+        ):
             LOG.debug(resource)
-            LOG.debug(resource.TemplateURL)
-            add_all_tags(resource.stack_template, params_and_tags)
-            add_parameters(resource.stack_template, params_and_tags[0])
+            LOG.debug(resource.title)
+            add_all_tags(resource.stack_template, settings, params, xtags)
+            if params:
+                add_parameters(resource.stack_template, params)
+            if (
+                not resource
+                or not hasattr(resource, "stack_template")
+                or not resource.stack_template
+            ):
+                return
             for stack_resname in resource.stack_template.resources:
-                add_object_tags(
-                    resource.stack_template.resources[stack_resname], params_and_tags[1]
-                )
-        elif isinstance(resource, Stack):
-            LOG.warn(resource_name)
-            LOG.warn(resource)
+                add_object_tags(resource.stack_template.resources[stack_resname], xtags)
