@@ -24,7 +24,6 @@ from troposphere import Ref, Join
 from ecs_composex.common import build_template, validate_kwargs
 from ecs_composex.common.cfn_params import ROOT_STACK_NAME_T, ROOT_STACK_NAME
 from ecs_composex.common.stacks import ComposeXStack
-from ecs_composex.common.tagging import add_all_tags, generate_tags_parameters
 from ecs_composex.rds.rds_db_template import (
     generate_database_template,
     create_db_subnet_group,
@@ -36,22 +35,15 @@ from ecs_composex.rds.rds_params import (
     DB_ENGINE_VERSION_T,
     DB_ENGINE_NAME_T,
 )
-from ecs_composex.vpc.vpc_conditions import (
-    USE_VPC_MAP_ID_CON_T,
-    USE_VPC_MAP_ID_CON,
-    NOT_USE_VPC_MAP_ID_CON_T,
-    NOT_USE_VPC_MAP_ID_CON,
-)
 from ecs_composex.vpc.vpc_params import (
     VPC_ID,
     VPC_ID_T,
-    VPC_MAP_ID,
     STORAGE_SUBNETS,
     STORAGE_SUBNETS_T,
 )
 
 
-def add_db_stack(root_template, dbs_subnet_group, db_name, db, **kwargs):
+def add_db_stack(root_template, dbs_subnet_group, db_name, db, settings):
     """
     Function to add the DB stack to the root stack
 
@@ -80,14 +72,13 @@ def add_db_stack(root_template, dbs_subnet_group, db_name, db, **kwargs):
         ROOT_STACK_NAME_T: Ref(ROOT_STACK_NAME),
     }
     parameters.update(non_stack_params)
-    db_template = generate_database_template(db_name, db, **kwargs)
+    db_template = generate_database_template(db_name, db)
     if db_template is None:
         return
-    root_template.add_resource(
-        ComposeXStack(
-            db_name, stack_template=db_template, Parameters=parameters, **kwargs
-        )
+    db_stack = ComposeXStack(
+        db_name, stack_template=db_template, stack_parameters=parameters
     )
+    root_template.add_resource(db_stack)
 
 
 def init_rds_root_template():
@@ -97,35 +88,24 @@ def init_rds_root_template():
     :return: template
     :rtype: troposphere.Template
     """
-    template = build_template(
-        "RDS Root Template", [VPC_MAP_ID, VPC_ID, STORAGE_SUBNETS]
-    )
-    template.add_condition(USE_VPC_MAP_ID_CON_T, USE_VPC_MAP_ID_CON)
-    template.add_condition(NOT_USE_VPC_MAP_ID_CON_T, NOT_USE_VPC_MAP_ID_CON)
+    template = build_template("RDS Root Template", [VPC_ID, STORAGE_SUBNETS])
     return template
 
 
-def generate_rds_templates(compose_content, tags=None, **kwargs):
+def generate_rds_templates(settings):
     """
     Function to generate the RDS root template for all the DBs defined in the x-rds section of the compose file
 
-    :param compose_content: the docker compose file content
-    :type compose_content: dict
-    :param kwargs: extra parameters
-    :param tags: tags and parameters to add to the resources
-    :type tags: tuple
+    :param ecs_composex.common.settings.ComposeXSettings settings: Settings for execution
 
     :return: rds_root_template, the RDS Root template with nested stacks
     :rtype: troposphere.Template
     """
     root_tpl = init_rds_root_template()
     dbs_subnet_group = create_db_subnet_group(root_tpl)
-    if tags is None:
-        tags = generate_tags_parameters(compose_content)
-    section = compose_content[RES_KEY]
+    section = settings.compose_content[RES_KEY]
     for db_name in section:
         add_db_stack(
-            root_tpl, dbs_subnet_group, db_name, section[db_name], **kwargs,
+            root_tpl, dbs_subnet_group, db_name, section[db_name], settings,
         )
-    add_all_tags(root_tpl, tags)
     return root_tpl
