@@ -31,8 +31,6 @@ respective AZ
 
 """
 
-from string import ascii_lowercase as alpha
-
 from troposphere import GetAtt, Tags, Ref, Sub, If
 from troposphere.ec2 import (
     Subnet,
@@ -46,9 +44,10 @@ from troposphere.ec2 import (
 from ecs_composex.common.cfn_conditions import USE_STACK_NAME_CON_T
 from ecs_composex.common.cfn_params import ROOT_STACK_NAME_T
 from ecs_composex.common.ecs_composex import CFN_EXPORT_DELIMITER as DELIM
+from ecs_composex.vpc import metadata
 
 
-def add_storage_subnets(template, vpc, az_range, layers):
+def add_storage_subnets(template, vpc, az_index, layers):
     """
     Function to add storage subnets inside the VPC
 
@@ -58,8 +57,8 @@ def add_storage_subnets(template, vpc, az_range, layers):
     :type template: troposphere.Template
     :param vpc: Vpc() for Ref()
     :type vpc: troposphere.ec2.Vpc
-    :param az_range: range for iteration over select AZs
-    :type az_range: list
+    :param az_index: List of AZ Index (a,b,c..)
+    :type az_index: list
 
     :returns: tuple() list of rtb, list of subnets
     """
@@ -68,36 +67,39 @@ def add_storage_subnets(template, vpc, az_range, layers):
         template=template,
         VpcId=Ref(vpc),
         Tags=Tags(Name="StorageRtb") + Tags({f"vpc{DELIM}usage": "storage"}),
+        Metadata=metadata,
     )
 
     subnets = []
-    for count, subnet_cidr in zip(az_range, layers["stor"]):
+    for index, subnet_cidr in zip(az_index, layers["stor"]):
         subnet = Subnet(
-            f"StorageSubnet{alpha[count].upper()}",
+            f"StorageSubnet{index.upper()}",
             template=template,
             CidrBlock=subnet_cidr,
             VpcId=Ref(vpc),
-            AvailabilityZone=Sub(f"${{AWS::Region}}{alpha[count]}"),
+            AvailabilityZone=Sub(f"${{AWS::Region}}{index}"),
             Tags=Tags(
                 Name=If(
                     USE_STACK_NAME_CON_T,
-                    Sub(f"${{AWS::StackName}}-Storage-{alpha[count]}"),
-                    Sub(f"${{{ROOT_STACK_NAME_T}}}-Storage-{alpha[count]}"),
+                    Sub(f"${{AWS::StackName}}-Storage-{index}"),
+                    Sub(f"${{{ROOT_STACK_NAME_T}}}-Storage-{index}"),
                 ),
             )
             + Tags({f"vpc{DELIM}usage": "storage", f"vpc{DELIM}vpc-id": Ref(vpc)}),
+            Metadata=metadata,
         )
         SubnetRouteTableAssociation(
-            f"StorageSubnetAssoc{alpha[count].upper()}",
+            f"StorageSubnetAssoc{index.upper()}",
             template=template,
             SubnetId=Ref(subnet),
             RouteTableId=Ref(rtb),
+            Metadata=metadata,
         )
         subnets.append(subnet)
     return [rtb], subnets
 
 
-def add_public_subnets(template, vpc, az_range, layers, igw, single_nat):
+def add_public_subnets(template, vpc, az_index, layers, igw, single_nat):
     """
     Function to add public subnets for the VPC
 
@@ -121,6 +123,7 @@ def add_public_subnets(template, vpc, az_range, layers, igw, single_nat):
         template=template,
         VpcId=Ref(vpc),
         Tags=Tags(Name="PublicRtb") + Tags({f"vpc{DELIM}usage": "public"}),
+        Metadata=metadata,
     )
     Route(
         "PublicDefaultRoute",
@@ -131,36 +134,36 @@ def add_public_subnets(template, vpc, az_range, layers, igw, single_nat):
     )
     subnets = []
     nats = []
-    for count, subnet_cidr in zip(az_range, layers["pub"]):
+    for index, subnet_cidr in zip(az_index, layers["pub"]):
         subnet = Subnet(
-            f"PublicSubnet{alpha[count].upper()}",
+            f"PublicSubnet{index.upper()}",
             template=template,
             CidrBlock=subnet_cidr,
             VpcId=Ref(vpc),
-            AvailabilityZone=Sub(f"${{AWS::Region}}{alpha[count]}"),
+            AvailabilityZone=Sub(f"${{AWS::Region}}{index}"),
             MapPublicIpOnLaunch=True,
             Tags=Tags(
                 Name=If(
                     USE_STACK_NAME_CON_T,
-                    Sub(f"${{AWS::StackName}}-Public-{alpha[count]}"),
-                    Sub(f"${{{ROOT_STACK_NAME_T}}}-Public-{alpha[count]}"),
+                    Sub(f"${{AWS::StackName}}-Public-{index}"),
+                    Sub(f"${{{ROOT_STACK_NAME_T}}}-Public-{index}"),
                 ),
             )
             + Tags({f"vpc{DELIM}usage": "public", f"vpc{DELIM}vpc-id": Ref(vpc)}),
+            Metadata=metadata,
         )
         if (single_nat and not nats) or not single_nat:
-            eip = EIP(
-                f"NatGatewayEip{alpha[count].upper()}", template=template, Domain="vpc"
-            )
+            eip = EIP(f"NatGatewayEip{index.upper()}", template=template, Domain="vpc")
             nat = NatGateway(
-                f"NatGatewayAz{alpha[count].upper()}",
+                f"NatGatewayAz{index.upper()}",
                 template=template,
                 AllocationId=GetAtt(eip, "AllocationId"),
                 SubnetId=Ref(subnet),
+                Metadata=metadata,
             )
             nats.append(nat)
         SubnetRouteTableAssociation(
-            f"PublicSubnetsRtbAssoc{alpha[count].upper()}",
+            f"PublicSubnetsRtbAssoc{index.upper()}",
             template=template,
             RouteTableId=Ref(rtb),
             SubnetId=Ref(subnet),
@@ -169,59 +172,62 @@ def add_public_subnets(template, vpc, az_range, layers, igw, single_nat):
     return [rtb], subnets, nats
 
 
-def add_apps_subnets(template, vpc, az_range, layers, nats):
+def add_apps_subnets(template, vpc, az_index, layers, nats):
     """
     Function to add application/hosts subnets to the VPC
 
     :param template: VPC Template()
     :param vpc: Vpc() for Ref()
-    :param az_range: range for iteration over select AZs
+    :param list az_index: index for the AZ (a,b,c ..)
     :param nats: list of NatGateway()
 
     :returns: tuple() list of rtb, list of subnets
     """
     subnets = []
     rtbs = []
-    if len(nats) < len(az_range):
+    if len(nats) < len(az_index):
         primary_nat = nats[0]
         nats = []
-        for _ in az_range:
+        for _ in az_index:
             nats.append(primary_nat)
-    for count, subnet_cidr, nat in zip(az_range, layers["app"], nats):
-        suffix = alpha[count].upper()
+    for index, subnet_cidr, nat in zip(az_index, layers["app"], nats):
+        suffix = index.upper()
         subnet = Subnet(
             f"AppSubnet{suffix}",
             template=template,
             CidrBlock=subnet_cidr,
             VpcId=Ref(vpc),
-            AvailabilityZone=Sub(f"${{AWS::Region}}{alpha[count]}"),
+            AvailabilityZone=Sub(f"${{AWS::Region}}{index}"),
             Tags=Tags(
                 Name=If(
                     USE_STACK_NAME_CON_T,
-                    Sub(f"${{AWS::StackName}}-App-{alpha[count]}"),
-                    Sub(f"${{{ROOT_STACK_NAME_T}}}-App-{alpha[count]}"),
+                    Sub(f"${{AWS::StackName}}-App-{index}"),
+                    Sub(f"${{{ROOT_STACK_NAME_T}}}-App-{index}"),
                 ),
             )
             + Tags({f"vpc{DELIM}usage": "application", f"vpc{DELIM}vpc-id": Ref(vpc)}),
+            Metadata=metadata,
         )
         rtb = RouteTable(
-            f"AppRtb{alpha[count].upper()}",
+            f"AppRtb{index.upper()}",
             template=template,
             VpcId=Ref(vpc),
-            Tags=Tags(Name=f"AppRtb{alpha[count].upper()}"),
+            Tags=Tags(Name=f"AppRtb{index.upper()}"),
+            Metadata=metadata,
         )
         Route(
-            f"AppRoute{alpha[count].upper()}",
+            f"AppRoute{index.upper()}",
             template=template,
             NatGatewayId=Ref(nat),
             RouteTableId=Ref(rtb),
             DestinationCidrBlock="0.0.0.0/0",
         )
         SubnetRouteTableAssociation(
-            f"SubnetRtbAssoc{alpha[count].upper()}",
+            f"SubnetRtbAssoc{index.upper()}",
             template=template,
             RouteTableId=Ref(rtb),
             SubnetId=Ref(subnet),
+            Metadata=metadata,
         )
         rtbs.append(rtb)
         subnets.append(subnet)
